@@ -211,8 +211,7 @@ class ArcaAPI():
                     post['view'] = int(soup2.find('span', 'vcol col-view').text.replace('\n', ''))
                     try:
                         post['comments'] = int(
-                            soup2.find('span', 'comment-count').text.replace('\n', '').replace('[', '').replace(']',
-                                                                                                                ''))
+                            soup2.find('span', 'comment-count').text.replace('\n', '').replace('[', '').replace(']',''))
                     except:
                         post['comments'] = 0
                     response['posts'].append(post)
@@ -247,24 +246,27 @@ class ArcaAPI():
         comments = soup.find_all('div', 'comment-wrapper')
         response['comment'] = []
         for x in comments:
-            comment = {}
             try:
-                comment['text'] = x.find('div', 'text').text
-            except:
+                comment = {}
                 try:
-                    comment['text'] = (x.find('img', 'emoticon').attrs['src'])
+                    comment['text'] = x.find('div', 'text').text
                 except:
-                    pass
-            try:
-                comment['user'] = x.find('span', 'user-info').find('a').attrs['data-filter']
-            except:
+                    try:
+                        comment['text'] = (x.find('img', 'emoticon').attrs['src'])
+                    except:
+                        pass
                 try:
-                    comment['user'] = x.find('span', 'user-info').find('span').attrs['data-filter']
+                    comment['user'] = x.find('span', 'user-info').find('a').attrs['data-filter']
                 except:
-                    pass
-            id_attrs = x.find('div', {'class': 'comment-item'}).attrs['id']
-            comment['comment_id'] = (int(id_attrs.replace('c_', '')))
-            response['comment'].append(comment)
+                    try:
+                        comment['user'] = x.find('span', 'user-info').find('span').attrs['data-filter']
+                    except:
+                        pass
+                id_attrs = x.find('div', {'class': 'comment-item'}).attrs['id']
+                comment['comment_id'] = (int(id_attrs.replace('c_', '')))
+                response['comment'].append(comment)
+            except:
+                pass
         response['content'] = (soup.find('div', 'fr-view article-content'))
         return response
 
